@@ -5,8 +5,8 @@
 
 #include "ev-document-type-builtins.h"
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-annotation.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-annotation.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-annotation.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-annotation.h"
 GType
 ev_annotation_type_get_type (void)
 {
@@ -79,8 +79,8 @@ ev_annotation_text_markup_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-annotations.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-annotations.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-annotations.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-annotations.h"
 GType
 ev_annotations_save_mask_get_type (void)
 {
@@ -112,8 +112,8 @@ ev_annotations_save_mask_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-find.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-find.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-find.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-find.h"
 GType
 ev_find_options_get_type (void)
 {
@@ -135,49 +135,8 @@ ev_find_options_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document.h"
-GType
-ev_document_load_flags_get_type (void)
-{
-  static volatile gsize g_define_type_id__volatile = 0;
- 
-  if (g_once_init_enter (&g_define_type_id__volatile)) {
-    static const GFlagsValue values[] = {
-      { EV_DOCUMENT_LOAD_FLAG_NONE, "EV_DOCUMENT_LOAD_FLAG_NONE", "none" },
-      { 0, NULL, NULL }
-    };
-    GType g_define_type_id = \
-       g_flags_register_static (g_intern_static_string ("EvDocumentLoadFlags"), values);
-      
-    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
-  }
-    
-  return g_define_type_id__volatile;
-}
-
-GType
-ev_document_error_get_type (void)
-{
-  static volatile gsize g_define_type_id__volatile = 0;
- 
-  if (g_once_init_enter (&g_define_type_id__volatile)) {
-    static const GEnumValue values[] = {
-      { EV_DOCUMENT_ERROR_INVALID, "EV_DOCUMENT_ERROR_INVALID", "invalid" },
-      { EV_DOCUMENT_ERROR_ENCRYPTED, "EV_DOCUMENT_ERROR_ENCRYPTED", "encrypted" },
-      { 0, NULL, NULL }
-    };
-    GType g_define_type_id = \
-       g_enum_register_static (g_intern_static_string ("EvDocumentError"), values);
-      
-    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
-  }
-    
-  return g_define_type_id__volatile;
-}
-
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-info.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-document-info.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-info.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document-info.h"
 GType
 ev_document_layout_get_type (void)
 {
@@ -310,8 +269,49 @@ ev_document_info_fields_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-file-exporter.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-file-exporter.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-document.h"
+GType
+ev_document_load_flags_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GFlagsValue values[] = {
+      { EV_DOCUMENT_LOAD_FLAG_NONE, "EV_DOCUMENT_LOAD_FLAG_NONE", "none" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_flags_register_static (g_intern_static_string ("EvDocumentLoadFlags"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
+GType
+ev_document_error_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GEnumValue values[] = {
+      { EV_DOCUMENT_ERROR_INVALID, "EV_DOCUMENT_ERROR_INVALID", "invalid" },
+      { EV_DOCUMENT_ERROR_ENCRYPTED, "EV_DOCUMENT_ERROR_ENCRYPTED", "encrypted" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_enum_register_static (g_intern_static_string ("EvDocumentError"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-file-exporter.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-file-exporter.h"
 GType
 ev_file_exporter_format_get_type (void)
 {
@@ -360,8 +360,8 @@ ev_file_exporter_capabilities_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-file-helpers.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-file-helpers.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-file-helpers.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-file-helpers.h"
 GType
 ev_compression_type_get_type (void)
 {
@@ -384,8 +384,8 @@ ev_compression_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-form-field.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-form-field.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-form-field.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-form-field.h"
 GType
 ev_form_field_text_type_get_type (void)
 {
@@ -448,8 +448,8 @@ ev_form_field_choice_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-link-action.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-link-action.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-link-action.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-link-action.h"
 GType
 ev_link_action_type_get_type (void)
 {
@@ -474,8 +474,8 @@ ev_link_action_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-link-dest.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-link-dest.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-link-dest.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-link-dest.h"
 GType
 ev_link_dest_type_get_type (void)
 {
@@ -503,8 +503,8 @@ ev_link_dest_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-selection.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-selection.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-selection.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-selection.h"
 GType
 ev_selection_style_get_type (void)
 {
@@ -526,8 +526,8 @@ ev_selection_style_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-transition-effect.h" */
-#include "/usr/src/ports/evince/evince-3.22.1-1.x86_64/src/evince-3.22.1/libdocument/ev-transition-effect.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-transition-effect.h" */
+#include "/usr/src/ports/evince/evince-3.24.1-1.i686/src/evince-3.24.1/libdocument/ev-transition-effect.h"
 GType
 ev_transition_effect_type_get_type (void)
 {
